﻿#cs
════════════════════════════════════════════════════════════════════════════════
I need a script that can extract a sentence containing a word written in a list.
The result is a text file with sentences extracted with a period as a sentence end limit.
After and before a period is the extracted sentence.

word list text file:
word 1
word 2
word 3

extracted sentence written in "sentence" text file:
this is word 1 sentence.
this is word 2 sentence.
this is word 3 sentence.
════════════════════════════════════════════════════════════════════════════════
#ce
#pragma compile(UPX, True)
#pragma compile(Console, True)
#pragma compile(FileDescription, 'extract a sentence containing word in text file')
; ──────────────────────────────────────
Opt('MustDeclareVars', True)
; ──────────────────────────────────────
;#include <AutoItConstants.au3>
#include <Array.au3>
#include <File.au3>
#include <MsgBoxConstants.au3>
#include <StringConstants.au3>
;~ #include <avEnv.au3>
;~ #include <avLib.au3>
; ──────────────────────────────────────
Local _
  $sText,                       _ ; source text to analyze
  $aWords,                      _ ; array of words to find in sentences
  $aResult,                     _ ; array of matching sentence(s) if any
  $i, $j, $k                      ; "traditional" indices and return code

; read two files containing source text and list of the words from
; let suppose that both files exist and they are _text_ files
;
$sText  = FileRead(@ScriptDir & '\vinnyMS-Text.txt')
$aWords = FileReadToArray(@ScriptDir & '\vinnyMS-Words.txt')
uf_PickSentences($sText, $aWords, $aResult)
$i = @error
If $i Then
  MsgBox($MB_ICONSTOP, @ScriptName, 'Error occurred; code=' & $i)
  Exit $i
EndIf
;
_ArrayDisplay($aResult, @ScriptName)
_FileWriteFromArray(@ScriptDir & '\vinnyMS-Result.txt', $aResult)
Exit 0
; ══════════════════════════════════════
#cs
uf_PickSentences() user function
Returns:
  True  = Ok!
  False = Something went wrong and sets @error to
          1 = bad/empty word list
          2 = no matching sentence found
          3 = StringRegExp failure
#ce
Func uf_PickSentences(      _ ; pick sentence(s) containing words to be found
    ByRef Const $psText,    _ ; source text
    ByRef Const $paWords,   _ ; array containing the words
    ByRef       $pvResult   _ ; array of matching sentence(s) if any
  )
  Local Const _
    $ciStripWSMode = BitOR($STR_STRIPLEADING, $STR_STRIPTRAILING), _  ; flags to strip left & right spaces
    $csRExp = '(?is)(?:\s*([^.]*\b(?:{1})\b[^.]*\.))'                 ; "{1}" is to be replaced with words list!
  Local _
    $sWList,  _
    $sRegEx,  _
    $iErr, $i
  For $i = 0 To UBound($aWords) - 1
    If Not StringIsSpace($aWords[$i]) Then
      $sWList &= ('|' & StringStripWS($aWords[$i], $ciStripWSMode))
    EndIf
  Next
  $sWList = StringTrimLeft($sWList, 1)                ; delete first "|" from the words list
  If StringIsSpace($sWList) Then
    Return SetError(1, 0, False)
  EndIf
  ;
  $sRegEx = StringReplace($csRExp, '{1}', $sWList)    ; build appropriate regular expression
  ;
  $pvResult = StringRegExp($psText, $sRegEx, $STR_REGEXPARRAYGLOBALMATCH) ; check source agains the regexp
  $iErr = @error
  ;
  Switch ($iErr)
    Case 0
      Return True
    Case 1
      Return SetError(2, 0, False)
    Case 2
      Return SetError(3, 0, False)
  EndSwitch
EndFunc

; ══════════════════════════════════════
